OC.L10N.register(
    "core",
    {
    "Settings" : "ده‌ستكاری",
    "Saving..." : "پاشکه‌وتده‌کات...",
    "No" : "نەخێر",
    "Yes" : "بەڵێ",
    "Ok" : "باشە",
    "Cancel" : "لابردن",
    "Error" : "هه‌ڵه",
    "Password" : "وشەی تێپەربو",
    "Share" : "هاوبەشی کردن",
    "Warning" : "ئاگاداری",
    "Add" : "زیادکردن",
    "Users" : "به‌كارهێنه‌ر",
    "Apps" : "به‌رنامه‌كان",
    "Admin" : "به‌ڕێوه‌به‌ری سه‌ره‌كی",
    "Help" : "یارمەتی",
    "Username" : "ناوی به‌کارهێنه‌ر",
    "Data folder" : "زانیاری فۆڵده‌ر",
    "Database user" : "به‌كارهێنه‌ری داتابه‌یس",
    "Database password" : "وشه‌ی نهێنی داتا به‌یس",
    "Database name" : "ناوی داتابه‌یس",
    "Database host" : "هۆستی داتابه‌یس",
    "Finish setup" : "كۆتایی هات ده‌ستكاریه‌كان",
    "Log out" : "چوونەدەرەوە",
    "Search" : "بگەڕێ",
    "New password" : "وشەی نهێنی نوێ",
    "Reset password" : "دووباره‌ كردنه‌وه‌ی وشه‌ی نهێنی"
},
"nplurals=2; plural=(n != 1);");
